# Weather Hue - The Colour of Temperature

# Import some Python Modules
import requests
import json
import pyowm
import sys
import argparse

requests.packages.urllib3.disable_warnings()

##################### Get Arguments ##################################

# Parse the arguments passed from the command line.
parser = argparse.ArgumentParser()
parser.add_argument('-g','--hueip',help='Philips Hue Bridge IP address',required=True)
parser.add_argument('-l','--location',help='Location of Philips Hue Bridge in fom used by OWM, e.g. London,UK',required=True)
parser.add_argument('-k','--hueapikey',help='Philips Hue API Key to allow access to Philips Hue Bridge API',required=True)
parser.add_argument('-j','--owmapikey',help='OWM API Key to allow access to get weather information from OWM (Open Weather Map)',required=True)
parser.add_argument('-i','--lightid',help='ID of the light you want to change colour of based on temperature.',required=True)
parser.add_argument('-d','--debugmode',help='Enable debug mode',default='0')


arguments = vars(parser.parse_args())

hueip = arguments['hueip']
location = arguments['location']
hueapikey = arguments['hueapikey']
owmapikey = arguments['owmapikey']
lightid = arguments['lightid']
debugmode = int(arguments['debugmode'])

##################### Set Static Variables #############################

tempunit = "celsius"

###################### Debug ###########################################

if debugmode == 1:
    print "\033[0;33;40mDEBUG:",arguments,"\033[0m"

##################### Get Current Weather Conditions ##################

owm = pyowm.OWM(owmapikey)
observation = owm.weather_at_place(location)
w = observation.get_weather()

temp = w.get_temperature(tempunit)
temp = float(str(temp['temp']))
temp = int(temp)

##################### Functions #######################################

def light_colour(payload,hueip,hueapikey,lightidi,debugmode):
    # Check the current state of the light, if its on change the colour, if its off do nothing.
    lightstateresult = requests.get('https://' + hueip + '/api/' + hueapikey + '/lights/' + lightid, verify=False)
    if lightstateresult.status_code != 200:
        # This means something went wrong.
        raise ApiError('GET /lights/ {}'.format(resp.status_code))
    # Convert the response object into JSON.
    lightstateresultjson = json.dumps(lightstateresult.json(),indent=2)
    # Convert the response object into a Python Dictionary
    lightstateresultdict = json.loads(lightstateresultjson)
    # Check the state of the light, if it is on, then change the colour, otherwise do nothing.
    if (lightstateresultdict['state']['on']) == True:
        print "Light State: ON"
        putresult = requests.put('https://' + hueip + '/api/' + hueapikey + '/lights/' + lightid + '/state',  data=json.dumps(payload), headers={"content-type":"application/json","cache-control":"no-cache"}, verify=False)
        print "Action: COLOUR"
        if debugmode == 1:
            print "\033[0;33;40mDEBUG:",putresult.text,"\033[0m"
    else:
        print "Light State: OFF"
        print "Action: NONE"

##################### Main Program Body ###############################

print "\033[0;32;40mWeather Hue - The Colour of Temperature\033[0m"
print "Location:",location
if (temp > 30):
    print "Temperature:",temp,"(",tempunit,")"
    print "Colour: RED"
    payload = {'xy':[0.6821, 0.3082]}
    light_colour(payload,hueip,hueapikey,lightid,debugmode)
elif (temp > 25) and (temp <= 29):
    print "Temperature:",temp,"(",tempunit,")"
    print "Colour: ORANGE"
    payload = {'xy':[0.5672, 0.4213]}
    light_colour(payload,hueip,hueapikey,lightid,debugmode)
elif (temp > 16) and (temp <= 24):
    print "Temperature:",temp,"(",tempunit,")"
    print "Colour: YELLOW"
    payload = {'xy':[0.4758, 0.4851]}
    light_colour(payload,hueip,hueapikey,lightid,debugmode)
elif (temp > 10) and (temp <= 15):
    print "Temperature:",temp,"(",tempunit,")"
    print "Colour: GREEN"
    payload = {'xy':[0.1829, 0.7171]}
    light_colour(payload,hueip,hueapikey,lightid,debugmode)
elif (temp > 5) and (temp <= 9):
    print "Temperature:",temp,"(",tempunit,")"
    print "Colour: LIGHT BLUE"
    payload = {'xy':[0.146, 0.208]}
    light_colour(payload,hueip,hueapikey,lightid,debugmode)
elif (temp <=4):
    print "Temperature:",temp,"(",tempunit,")"
    print "Colour: DARK BLUE"
    payload = {'xy':[0.154, 0.0803]}
    light_colour(payload,hueip,hueapikey,lightid,debugmode)
else:
    print "Broken"
